from sspo_db.model.stakeholder.models import Person, Developer
from sspo_db.service.stakeholder.service import PersonService, DeveloperService
from sspo_db.service.core.service import ApplicationReferenceService

class ApplicationPerson():
    
    def __init__(self):
        self.person_service = PersonService()
        self.application_reference_service = ApplicationReferenceService()
    
    def retrive_by_uuid(self, uuid):
        return self.person_service.get_by_uuid(uuid)
    

    def retrive_person_by_external_uuid (self, external_uuid):
        application_reference = self.application_reference_service.get_by_external_uuid(external_uuid)
        return self.person_service.get_by_uuid(application_reference.internal_uuid)

    def create_person(self, name, email, organization, description = ""):
        
        person = Person()
        person.name = name
        person.description = description
        person.email = email 
        person.organization = organization

        self.person_service.create(person)

        return person
        

class ApplicationStakeholder():

    def __ini__(self):
        self.develope_service = DeveloperService()
    
    def create_developer(self, person, team, team_role = ""):
        
        developer = Developer()
        developer.person = person
        developer.team = team 
        developer.team_role = team_role

        self.develope_service(developer)

    
    


from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from sspo_db.model.stakeholder.models import *
from sspo_db.service.base_service import BaseService

class PersonService(BaseService):
    
    def __init__(self):
        super(PersonService,self).__init__(Person)
    
    def retrive_person_by_external_id(self, external_id):
        pass

class TeamMemberService(BaseService):
    def __init__(self):
        super(TeamMemberService,self).__init__(TeamMember)

class DeveloperService(BaseService):
    def __init__(self):
        super(DeveloperService,self).__init__(Developer)

class ScrumMasterService(BaseService):
    def __init__(self):
        super(ScrumMasterService,self).__init__(ScrumMaster)

class ProductOwnerService(BaseService):
    def __init__(self):
        super(ProductOwnerService,self).__init__(ProductOwner)

class ClientService(BaseService):
    def __init__(self):
        super(ClientService,self).__init__(Client)


from sspo_db.model.core.models import ApplicationReference
from sspo_db.service.core.service import ApplicationReferenceService, ApplicationService

class ApplicationApplicationReference():

    def __init__(self):
        self.application_reference_service = ApplicationReferenceService()

    
    def create(self,name, description, application, external_id, external_type_entity, external_url,internal_uuid, entity_name ):

        application_reference = ApplicationReference()
        application_reference.name = entity_name+ " - "+name
        application_reference.description = description
        application_reference.application = application.id
        application_reference.external_id = external_id
        application_reference.external_url = external_url
        application_reference.external_type_entity = external_type_entity
        application_reference.internal_uuid = internal_uuid
        application_reference.entity_name = entity_name

        self.application_reference_service.create(application_reference)

        return application_reference

    def get_by_external_uuid(self,external_id):
        return self.session.query(ApplicationReference).filter(ApplicationReference.external_id == external_id).first()
                    